@@ -388,15 +388,31 @@ class varsShare:
         """
         cmdLine = "/proc/cmdline"
         calculateParam = "calculate"
+        names = ("lang","keymap","timezone",
+                    "resolution","video","composite")
         # try get timezone from kernel calculate param
         try:
+            if type(num) == str and not num.isdigit():
+                name = num
+                num = names.index(name)
+            else:
+                name = names[int(num)]
             for param in open(cmdLine,"r").read().split(" "):
                 parname,op,value = param.partition("=")
                 if parname == calculateParam and op == "=":
-                    values = value.split(",")
-                    if len(values) > num and values[num].strip():
-                        return values[num].strip()
-        except IOError,e:
+                    # new format
+                    if ":" in value:
+                        params = dict(
+                                map(lambda x:x.partition(':')[0::2],
+                                filter(lambda x:x,
+                                value.split(','))))
+                        return params.get(name,"").strip()
+                    # old format
+                    else:
+                        values = value.split(",")
+                        if len(values) > num and values[num].strip():
+                            return values[num].strip()
+        except (IOError,ValueError,IndexError),e:
             return ""
 
     def getValueFromConfig(self,config,name):
@@ -548,3 +564,29 @@ class varsShare:
             return progname
         else:
             return False
+
+    def getVideoByDefault(self,drivers_list):
+        """Get video by default, or wrong specified"""
+        workedModules = map(lambda x:x[0],
+                        filter(lambda x:x[1].isdigit() and int(x[1])>0,
+                        map(lambda x:x.split()[:3:2],
+                        open('/proc/modules','r'))))
+        if "nvidia" in drivers_list:
+            defaultNvidia = "nvidia"
+        elif "nouveau" in workedModules:
+            defaultNvidia = "nouveau"
+        else:
+            defaultNvidia = "nv"
+        defaultDriver = {
+            'vesa':'vesa',
+            'nvidia':defaultNvidia,
+            'ati':'fglrx' if "fglrx" in drivers_list else "radeon",
+            'intel':'intel',
+            'via':'via',
+            'vmware':'vmware'}
+        hr_video = self.Get('hr_video')
+        if hr_video in defaultDriver and \
+            defaultDriver[hr_video] in drivers_list:
+            return defaultDriver[hr_video]
+        else:
+            return "vesa"
